==> org.eclipse.scout.rt.ui.swing.source_3.7.2.201202140505.jar: org/eclipse/scout/rt/ui/swing/SwingIcons.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.rt.ui.swing;

/**
 * These are icons that are only used in the UI i.e. they appear nowhere in the model code.
 */
public interface SwingIcons {

  String ColumnFilterEnabled = "column_filter_enabled";
  String FolderOpen = "folder_open";
  String FolderClosed = "folder_closed";
  String Mandantory = "mandatory";
  String MandantoryDisabled = "mandatory_disabled";
  String IconMenu = "icon_menu";
  String IconSlider = "icon_slider";
  String NetworkLatencyGreen = "network_latency_green";
  String NetworkLatencyYellow = "network_latency_yellow";
  String NetworkLatencyRed = "network_latency_red";
  String NavigationBackward = "navigation_backward";
  String NavigationForward = "navigation_forward";
  String NavigationMenu = "navigation_menu";
  String NavigationBtnBack = "nw_btn_back";
  String NavigationIcoBack = "nw_ico_back";
  String NavigationBtnForward = "nw_btn_forward";
  String NavigationIcoForward = "nw_ico_forward";
  String NavigationBtnStopRefresh = "nw_btn_stop_refresh";
  String NavigationIcoRefresh = "nw_ico_refresh";
  String NavigationGlow = "nw_glow";
  String NavigationIcoHistory = "nw_ico_history";
  String NavigationIcoStop = "nw_ico_stop";
  String NavigationShadowBack = "nw_shadow_back";
  String NavigationShadowForward = "nw_shadow_forward";
  String NavigationShadow = "nw_shadow";
  String NavigationShadowStopRefresh = "nw_shadow_stop_refresh.png";
  String ToolTab = "tool_tab";
  String Tooltip = "tooltip";
  String ViewTabLeft = "view_tab_left";
  String ViewTabRight = "view_tab_right";
  String Splash = "splash";
  String StatusInfo = "status_info";
  String StatusError = "status_error";
  String StatusWarning = "status_warning";
  String StatusInterrupt = "status_interrupt";

}

==> org.eclipse.scout.rt.ui.swing.source_5.0.100.20150806-0807.jar: org/eclipse/scout/rt/ui/swing/SwingIcons.java <==
/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.scout.rt.ui.swing;

/**
 * These are icons that are only used in the UI i.e. they appear nowhere in the model code.
 */
public interface SwingIcons {
  String TableColumnFilterActive = "table_column_filter_active";
  String TableSortAsc = "table_sort_asc";
  String TableSortDesc = "table_sort_desc";
  String TableCustomColumn = "table_custom_column";

  String Mandantory = "mandatory";
  String MandantoryDisabled = "mandatory_disabled";

  String Logo = "logo";

  String NetworkLatencyGreen = "network_latency_green";
  String NetworkLatencyYellow = "network_latency_yellow";
  String NetworkLatencyRed = "network_latency_red";

  String NavigationBack = "navigation_back";
  String NavigationForward = "navigation_forward";
  String NavigationRefresh = "navigation_refresh";
  String NavigationStop = "navigation_stop";
  String NavigationHistory = "navigation_history";

  String Splash = "splash";

  String StatusInterrupt = "status_interrupt";

  String Window = "window";
  String Window16 = "window16";
  String Window32 = "window32";
  String Window48 = "window48";
  String Window256 = "window256";

  String Tray = "tray";

}
